Learn R Programming

TP.idm (version 1.5.1)

TP.idm-package: tools:::Rd_package_title("TP.idm")

Description

Estimation of transition probabilities for the illness-death model. Both the Aalen-Johansen estimator for a Markov model and a novel non-Markovian estimator by de Uña-Álvarez and Meira-Machado (2015) <doi:10.1111/biom.12288>, see also Balboa and de Uña-Álvarez (2018) <doi:10.18637/jss.v083.i10>, are included.

Arguments

Author

tools:::Rd_package_author("TP.idm")

Maintainer: tools:::Rd_package_maintainer("TP.idm")

Details

The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("TP.idm") tools:::Rd_package_indices("TP.idm")

This package incorporates the function TPidm which can be used to compute a nonparametric transition probability matrix for the illness-death model. For a complete list of functions use library(help=TP.idm).

References

Andersen P. K., Borgan O., Gill R. D. and Keiding N. (1993). Statistical models based on counting processes. Springer Series in Statistics. New York, NY: Springer.

Datta S. and Satten G. A. (2001). Validity of the Aalen-Johansen estimators of stage occupation probabilities and Nelson-Aalen estimators of integrated transition hazards for non-Markov models. Statistics and Probability Letters 55(4), 403--411.

de Uña-Álvarez J. and Meira-Machado L. (2015). Nonparametric estimation of transition probabilities in a non-Markov illness-death model: a comparative study. Biometrics 71, 364--375.

Meira-Machado L. F., de Uña-Álvarez J. and Cadarso-Suárez C. (2006). Nonparametric estimation of transition probabilities in a non-Markov illness-death model. Lifetime Data Annal 12(3), 325--344.

Balboa-Barreiro V., de Uña-Álvarez J. (2018). Estimation of Transition Probabilities for the Illness-Death Model: Package TP.idm. Journal of Statistical Software 83(10), 1--19.

Examples

Run this code
data(colonTP)

# create a TPidm object with s = 0, t = "last" (default),
# CI = TRUE (default) and method = "AJ":
aj0ci <- TPidm(colonTP, s = 0, method = "AJ")
summary(aj0ci) # summarizing the results
plot(aj0ci) # plotting all occupation probabilities

Run the code above in your browser using DataLab